/* Reflow Oven Controller
*
* Copyright (C) 2020  Mario Hüttel <mario.huettel@gmx.net>
*
* This file is part of the Reflow Oven Controller Project.
*
* The reflow oven controller is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License version 2 as
* published by the Free Software Foundation.
*
* The Reflow Oven Control Firmware is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with the reflow oven controller project.
* If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * @defgroup main-cycle-counter Main Cycle Counter
 * The main cycle counter is incremented after every loop run of the main loop in main.c
 * @{
 */

#ifndef __MAIN_CYCLE_COUNTER_H__
#define __MAIN_CYCLE_COUNTER_H__

#include <stdint.h>

/**
 * @brief Initialize the main cycle counter and reset to 0. This also enables the core cycle counter
 * This function can be called multiple times.
 */
void main_and_core_cycle_counter_init(void);

/**
 * @brief Reset the main cycle counter.
 * @note This does not reset the core cycle counter
 */
void main_cycle_counter_reset(void);

/**
 * @brief Increment the main cycle counter by 1
 */
void main_cycle_counter_inc(void);

/**
 * @brief Get the current main cycle counter value
 * @return Value
 */
uint64_t main_cycle_counter_get(void);

/**
 * @brief Reset the core cycle counter to 0
 */
void core_cycle_counter_reset(void);

/**
 * @brief Get the current value of the core cycle counter
 * 
 * @return uint32_t Counter value
 */
uint32_t core_cycle_counter_get(void);

#endif /* __MAIN_CYCLE_COUNTER_H__ */

/** @} */
